==> ROC_1.1.1.tar.gz: ROC/man/rocdemo.sca.Rd <==
\name{rocdemo.sca}
\alias{rocdemo.sca}
\alias{dxrule.sca}
\title{ function to build objects of class 'rocc'  }
\description{
rocdemo.sca -- demonstrate 'rocc' class construction
using a scalar marker and simple functional rule
}
\usage{
rocdemo.sca(truth, data, rule, 
       cutpts=NA,
       markerLabel="unnamed marker", caseLabel="unnamed diagnosis")
}
\arguments{
  \item{truth}{ true classification of objects. Must take values 0 or 1.}
  \item{data}{ quantitative markers used to classify}
  \item{rule}{ rule: a function with arguments (x, thresh) returning 0 or 1}
  \item{cutpts}{ values of thresholds}
  \item{markerLabel}{ textual label describing marker}
  \item{caseLabel}{ textual label describing classification}
}
\details{

  dxrule.sca is function (x, thresh) ifelse(x > thresh, 1, 0)

  The default value of argument cutpts is a point less than min(data), points
  separating the unique values of data and a point greater than max(data).

}
\value{
an object of S4 class rocc
}
\references{  }
\author{Vince Carey (stvjc@channing.harvard.edu)  }
\note{  }


\seealso{AUC}

\examples{
set.seed(123)
R1 <- rocdemo.sca( rbinom(40,1,.3), rnorm(40), dxrule.sca,
   caseLabel="new case", markerLabel="demo Marker" )
plot(R1, line=TRUE, show.thresh=TRUE)

truth <- c(0, 1, 0, 1, 1, 0, 1, 1)
data <- c(2, 3, 4, 4, 5, 6, 7, 8)
R2 <- rocdemo.sca(truth, data, dxrule.sca)
plot(R2, line=TRUE, show.thresh=TRUE)
R3 <- rocdemo.sca(truth, data, function(x, thresh) 1 - dxrule.sca(x, thresh))
if (AUC(R2) + AUC(R3) != 1) stop('Sum of AUCs should be 1.')
}
\keyword{ models }

==> ROC_1.18.0.tar.gz: ROC/man/rocdemo.sca.Rd <==
\name{rocdemo.sca}
\alias{rocdemo.sca}
\alias{dxrule.sca}
\title{ function to build objects of class 'rocc'  }
\description{
rocdemo.sca -- demonstrate 'rocc' class construction
using a scalar marker and simple functional rule
}
\usage{
rocdemo.sca(truth, data, rule=NULL, 
       cutpts=NA,
       markerLabel="unnamed marker", caseLabel="unnamed diagnosis")
}
\arguments{
  \item{truth}{ true classification of objects. Must take values 0 or 1.}
  \item{data}{ quantitative markers used to classify}
  \item{rule}{ rule: a function with arguments (x, thresh) returning 0
    or 1. If no rule is provided the standard rule \code{dxrule.sca} is
    assumed and a faster implementation utilized.}
  \item{cutpts}{ values of thresholds}
  \item{markerLabel}{ textual label describing marker}
  \item{caseLabel}{ textual label describing classification}
}
\details{

  dxrule.sca is function (x, thresh) ifelse(x > thresh, 1, 0)

  The default value of argument cutpts is a point less than min(data), points
  separating the unique values of data and a point greater than max(data).

}
\value{
an object of S4 class rocc
}
\references{  }
\author{Vince Carey (stvjc@channing.harvard.edu)  }
\note{  }


\seealso{AUC}

\examples{
set.seed(123)
R1 <- rocdemo.sca( rbinom(40,1,.3), rnorm(40), caseLabel="new case", markerLabel="demo Marker" )
plot(R1, line=TRUE, show.thresh=TRUE)

truth <- c(0, 1, 0, 1, 1, 0, 1, 1)
data <- c(2, 3, 4, 4, 5, 6, 7, 8)
R2 <- rocdemo.sca(truth, data, dxrule.sca)
plot(R2, line=TRUE, show.thresh=TRUE)
R3 <- rocdemo.sca(truth, data, function(x, thresh) 1 - dxrule.sca(x, thresh))
if (AUC(R2) + AUC(R3) != 1) stop('Sum of AUCs should be 1.')
}
\keyword{ models }
